#ifndef CHROMEOS_CAMERA_LIB_BLUR_DETECTION_BLUR_DETECTOR_H_
#define CHROMEOS_CAMERA_LIB_BLUR_DETECTION_BLUR_DETECTOR_H_

#include <memory>

namespace chromeos_camera {

class BlurDetector{
 public:
  virtual ~BlurDetector() = default;

  // Given JPEG data, get a probability for how likely it is that the
  // lens is dirty from |dirty_probability|.
  // All parameters are required.
  virtual bool CalculateDirtyLensProbFromJPEGImage(const uint8_t* jpeg_data,
                      uint32_t image_size, float* dirty_probability) = 0;

  // Given JPEG data, convert the image to gray, run Canny algorithm and
  // get the variance from |canny_variance|.
  // All parameters are required.
  virtual bool CalculateCannyVarFromJPEGImage(const uint8_t* jpeg_data,
                      uint32_t image_size, int* canny_variance) = 0;

  // TODO(b/258122446): Detect Blur from YUV Format
};

extern "C" {

std::unique_ptr<BlurDetector> CreateBlurDetector();
typedef decltype(&CreateBlurDetector) CreateBlurDetectorFn;

}  // extern "C"

}  // namespace chromeos_camera

#endif  // CHROMEOS_CAMERA_LIB_BLUR_DETECTION_BLUR_DETECTOR_H_
